@@ -11,7 +11,7 @@
 
 This project provides a CDK construct to create an S3 Bucket with some security pre-sets. It uses usual [s3.BucketProps](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-s3.BucketProps.html) and overrides these key-value pairs:
 
-```typescript
+```python
 {
   blockPublicAccess: s3.BlockPublicAccess.BLOCK_ALL,
   enforceSSL: true,
@@ -65,7 +65,7 @@ npm install @pepperize/cdk-private-bucket
 
 See [API.md](https://github.com/pepperize/cdk-private-bucket/blob/main/API.md).
 
-```typescript
+```python
 import { PrivateBucket } from "@pepperize/cdk-private-bucket";
 
 const bucket = new PrivateBucket(this, "PrivateBucket", {});
@@ -81,6 +81,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
@@ -154,6 +156,10 @@ class PrivateBucket(
         :param website_redirect: Specifies the redirect behavior of all requests to a website endpoint of a bucket. If you specify this property, you can't specify "websiteIndexDocument", "websiteErrorDocument" nor , "websiteRoutingRules". Default: - No redirection.
         :param website_routing_rules: Rules that define when a redirect is applied and the redirect behavior. Default: - No redirection rules.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PrivateBucket.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = PrivateBucketProps(
             access_control=access_control,
             auto_delete_objects=auto_delete_objects,
@@ -275,6 +281,33 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         '''
         if isinstance(website_redirect, dict):
             website_redirect = aws_cdk.aws_s3.RedirectTarget(**website_redirect)
+        if __debug__:
+            type_hints = typing.get_type_hints(PrivateBucketProps.__init__)
+            check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
+            check_type(argname="argument auto_delete_objects", value=auto_delete_objects, expected_type=type_hints["auto_delete_objects"])
+            check_type(argname="argument block_public_access", value=block_public_access, expected_type=type_hints["block_public_access"])
+            check_type(argname="argument bucket_key_enabled", value=bucket_key_enabled, expected_type=type_hints["bucket_key_enabled"])
+            check_type(argname="argument bucket_name", value=bucket_name, expected_type=type_hints["bucket_name"])
+            check_type(argname="argument cors", value=cors, expected_type=type_hints["cors"])
+            check_type(argname="argument encryption", value=encryption, expected_type=type_hints["encryption"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument enforce_ssl", value=enforce_ssl, expected_type=type_hints["enforce_ssl"])
+            check_type(argname="argument event_bridge_enabled", value=event_bridge_enabled, expected_type=type_hints["event_bridge_enabled"])
+            check_type(argname="argument intelligent_tiering_configurations", value=intelligent_tiering_configurations, expected_type=type_hints["intelligent_tiering_configurations"])
+            check_type(argname="argument inventories", value=inventories, expected_type=type_hints["inventories"])
+            check_type(argname="argument lifecycle_rules", value=lifecycle_rules, expected_type=type_hints["lifecycle_rules"])
+            check_type(argname="argument metrics", value=metrics, expected_type=type_hints["metrics"])
+            check_type(argname="argument object_ownership", value=object_ownership, expected_type=type_hints["object_ownership"])
+            check_type(argname="argument public_read_access", value=public_read_access, expected_type=type_hints["public_read_access"])
+            check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
+            check_type(argname="argument server_access_logs_bucket", value=server_access_logs_bucket, expected_type=type_hints["server_access_logs_bucket"])
+            check_type(argname="argument server_access_logs_prefix", value=server_access_logs_prefix, expected_type=type_hints["server_access_logs_prefix"])
+            check_type(argname="argument transfer_acceleration", value=transfer_acceleration, expected_type=type_hints["transfer_acceleration"])
+            check_type(argname="argument versioned", value=versioned, expected_type=type_hints["versioned"])
+            check_type(argname="argument website_error_document", value=website_error_document, expected_type=type_hints["website_error_document"])
+            check_type(argname="argument website_index_document", value=website_index_document, expected_type=type_hints["website_index_document"])
+            check_type(argname="argument website_redirect", value=website_redirect, expected_type=type_hints["website_redirect"])
+            check_type(argname="argument website_routing_rules", value=website_routing_rules, expected_type=type_hints["website_routing_rules"])
         self._values: typing.Dict[str, typing.Any] = {}
         if access_control is not None:
             self._values["access_control"] = access_control
